import type {SchoolClassDetailResponseModel, WorkGroupDetailResponseModel} from '@/helpers/models';
import {SubElement} from '@univention/univention-veb';

export const groupDetailResponse: SchoolClassDetailResponseModel | WorkGroupDetailResponseModel = {
  url: '',
  allowedActions: ['save'],
  pages: [
    {
      label: 'General',
      name: 'general',
      fieldsets: [
        {
          label: 'Basic settings',
          name: 'general__basic',
          rows: [
            [
              {
                type: 'UInputText',
                props: {
                  name: 'idiSchoolyear',
                  label: 'School year',
                  required: false,
                  access: 'write',
                },
              },
              {
                type: 'UInputText',
                props: {
                  name: 'description',
                  label: 'Description',
                  required: true,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'name',
                  label: 'Name',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UMultiObjectSelect',
                props: {
                  name: 'users',
                  label: 'Users',
                  access: 'write',
                  searchStandby: false,
                  initialRows: [
                    {
                      id: 'max.mustermann',
                      attributes: {
                        username: {
                          value: 'max.mustermann',
                          access: 'read',
                        },
                        firstname: {
                          value: 'Max',
                          access: 'read',
                        },
                        lastname: {
                          value: 'Mustermann',
                          access: 'read',
                        },
                        role: {
                          value: 'student',
                          access: 'read',
                        },
                      },
                    },
                  ],
                  columns: [
                    {
                      label: 'Username',
                      attribute: 'username',
                    },
                    {
                      label: 'Firstname',
                      attribute: 'firstname',
                    },
                    {
                      label: 'Lastname',
                      attribute: 'lastname',
                    },
                    {
                      label: 'Role',
                      attribute: 'role',
                    },
                  ],
                  searchRows: [],
                  searchElements: [
                    {
                      type: SubElement.UComboBox,
                      props: {
                        label: 'Role',
                        name: 'role',
                        options: [
                          {
                            value: 'role1',
                            label: 'Role 1',
                          },
                          {
                            value: 'role2',
                            label: 'Role 2',
                          },
                        ],
                      },
                    },
                    {
                      type: SubElement.UComboBox,
                      props: {
                        label: 'Schoolclass',
                        name: 'schoolClass',
                        options: [
                          {
                            value: 'class1',
                            label: 'Class 1',
                          },
                          {
                            value: 'class2',
                            label: 'Class 2',
                          },
                        ],
                      },
                    },
                    {
                      type: SubElement.UComboBox,
                      props: {
                        label: 'Workgroup',
                        name: 'workgroup',
                        options: [
                          {
                            value: 'workgroup1',
                            label: 'Workgroup 1',
                          },
                          {
                            value: 'workgroup2',
                            label: 'Workgroup 2',
                          },
                        ],
                      },
                    },
                    {
                      type: SubElement.UInputText,
                      props: {
                        label: 'Suche',
                        name: 'quickSearch',
                      },
                    },
                  ],
                  searchColumns: [
                    {
                      label: 'Username',
                      attribute: 'username',
                    },
                    {
                      label: 'Firstname',
                      attribute: 'firstname',
                    },
                    {
                      label: 'Lastname',
                      attribute: 'lastname',
                    },
                    {
                      label: 'Role',
                      attribute: 'role',
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'divisClasstype',
                  label: 'Group type',
                  required: false,
                  access: 'write',
                  options: [
                    {
                      label: 'Class',
                      value: 'class',
                    },
                    {
                      label: 'Offer',
                      value: 'offer',
                    },
                  ],
                },
              },
              {
                type: 'UComboBox',
                props: {
                  name: 'divisCoursetype',
                  label: 'Course type',
                  required: false,
                  access: 'write',
                  options: [
                    {
                      label: 'Course 1',
                      value: 'type1',
                    },
                    {
                      label: 'Course 2',
                      value: 'type2',
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  label: 'Source',
                  name: 'groupSourceId',
                  required: false,
                  access: 'write',
                },
              },
              {
                type: 'UInputText',
                props: {
                  label: 'Record ID',
                  name: 'recordUID',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  label: 'LMS enabled',
                  name: 'isLmsGroup',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  label: 'IServ enabled',
                  name: 'isIservGroup',
                  required: false,
                  access: 'write',
                },
              },
            ],
          ],
        },
      ],
    },
    {
      label: 'Account',
      name: 'account',
      fieldsets: [
        {
          label: 'General',
          name: 'account__general',
          rows: [
            [
              {
                type: 'UInputDate',
                props: {
                  label: 'Creation date',
                  name: 'createTimestamp',
                  required: false,
                  access: 'write',
                },
              },
              {
                type: 'UInputDate',
                props: {
                  label: 'Date of last change',
                  name: 'modifyTimestamp',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  label: 'Activation date',
                  name: 'divisStartdate',
                  required: false,
                  access: 'write',
                },
              },
              {
                type: 'UInputDate',
                props: {
                  label: 'Expiration date',
                  name: 'divisEnddate',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  label: 'Scheduled deletion date',
                  name: 'purgeDate',
                  required: false,
                  access: 'write',
                },
              },
            ],
          ],
        },
        {
          label: 'SAML settings',
          name: 'account__samlSettings',
          rows: [
            {
              type: 'UMultiSelect',
              props: {
                name: 'serviceprovidergroup',
                label: 'SAML service provider',
                required: false,
                columns: [
                  {
                    label: 'Select all',
                    attribute: 'label',
                  },
                ],
                rows: [
                  {
                    id: 'sp1',
                    attributes: {
                      label: {
                        value: 'Service provider 1',
                        access: 'read',
                      },
                    },
                  },
                  {
                    id: 'sp2',
                    attributes: {
                      label: {
                        value: 'Service provider 2',
                        access: 'read',
                      },
                    },
                  },
                  {
                    id: 'sp3',
                    attributes: {
                      label: {
                        value: 'Service provider 3',
                        access: 'read',
                      },
                    },
                  },
                ],
              },
            },
          ],
        },
      ],
    },
  ],
  values: {
    idiSchoolyear: '2020',
    description: 'description',
    name: 'username',
    users: ['max.mustermann'],
    divisClasstype: 'class',
    divisCoursetype: 'type1',
    groupSourceId: 'source',
    recordUID: 'record id',
    isLmsGroup: true,
    isIservGroup: true,
    createTimestamp: '2020-01-01',
    modifyTimestamp: '2020-01-01',
    divisStartdate: '2020-01-01',
    divisEnddate: '2020-01-01',
    purgeDate:  '2020-01-01',
    serviceprovidergroup: [],
  },
};
